.DocSearch-Container {
  z-index: 1050;
}

.search-button__wrapper.show .search-button__overlay,
.search-button__wrapper.show .search-button__search-container {
  display: none;
}

.DocSearch-Hits mark {
  padding: 0;
}

kbd:not(.compound) {
  padding: 0rem 0rem;
}

kbd.DocSearch-Commands-Key {
  border: 0;
  box-shadow: var(--docsearch-key-shadow);
  margin: 1px 5px 1px 0px;
  padding: inherit;
}
