:root {
  --docsearch-searchbox-background: var(--color-sidebar-search-background);
  --docsearch-key-gradient: none;
}

.DocSearch-Button {
  margin: 0;
  border-radius: 0;
  width: 100%;
  border: none;
  border-top: 1px solid var(--color-sidebar-search-border);
  border-bottom: 1px solid var(--color-sidebar-search-border);
}

kbd.DocSearch-Button-Key {
  display: flex;
  border: unset;
  border-radius: 3px;
  box-shadow: var(--docsearch-key-shadow);
  color: var(--docsearch-muted-color);
  margin: 0 0.4em 0 0;
  padding: 0 0 2px;
}

kbd.DocSearch-Commands-Key {
  box-shadow: var(--docsearch-key-shadow);
  border-radius: 2px;
  border: unset;
  display: flex;
  margin: 0 4px 0 0;
  padding: 0 0 1px;
  font-size: unset;
  color: var(--docsearch-muted-color);
}

/* Dark mode */
body[data-theme='dark'] {
  --docsearch-text-color: rgb(245, 246, 247);
  --docsearch-container-background: rgba(9, 10, 17, 0.8);
  --docsearch-modal-background: rgb(21, 23, 42);
  --docsearch-modal-shadow: inset 1px 1px 0 0 rgb(44, 46, 64),
    0 3px 8px 0 rgb(0, 3, 9);
  --docsearch-searchbox-background: rgb(9, 10, 17);
  --docsearch-searchbox-focus-background: #000;
  --docsearch-hit-color: rgb(190, 195, 201);
  --docsearch-hit-shadow: none;
  --docsearch-hit-background: rgb(9, 10, 17);
  --docsearch-key-gradient: linear-gradient(
    -26.5deg,
    rgb(86, 88, 114) 0%,
    rgb(49, 53, 91) 100%
  );
  --docsearch-key-shadow: inset 0 -2px 0 0 rgb(40, 45, 85),
    inset 0 0 1px 1px rgb(81, 87, 125), 0 2px 2px 0 rgba(3, 4, 9, 0.3);
  --docsearch-footer-background: rgb(30, 33, 54);
  --docsearch-footer-shadow: inset 0 1px 0 0 rgba(73, 76, 106, 0.5),
    0 -4px 8px 0 rgba(0, 0, 0, 0.2);
  --docsearch-logo-color: rgb(255, 255, 255);
  --docsearch-muted-color: rgb(127, 132, 151);
}

